@@ -2,7 +2,8 @@ import re
 import hashlib
 import unicodedata
 import string
-
+from os import path
+import pathlib
 
 def clean_query(query):
     # A pure copy-paste of regex patterns from DeezloaderRemix
@@ -19,6 +20,13 @@ def clean_query(query):
     return query
 
 
+def create_folders(directory):
+    directory = path.normpath(directory)
+
+    p = pathlib.Path(directory)
+    p.mkdir(parents=True, exist_ok=True)
+
+
 def clean_filename(filename):
     # https://gist.github.com/wassname/1393c4a57cfcbf03641dbc31886123b8
     whitelist = "-_.() %s%s" % (string.ascii_letters, string.digits) + "',\""
